# Charger les packages nécessaires
library(httr)
library(jsonlite)
library(dplyr)
library(DT)
library(stringr)
# Récupérer le token GitHub depuis l'environnement


# Fonction pour récupérer les commits d'un projet GitHub avec clé API
get_github_commits <- function(repo) {
  url <- paste0("https://api.github.com/repos/", repo, "/commits")
  response <- GET(url, authenticate(Sys.getenv("GITHUB_PAT"), ""))  # Utilisation de la clé API
  if (status_code(response) != 200) {
    stop("Failed to fetch commits from GitHub API")
  }
  commits <- fromJSON(content(response, "text"), flatten = TRUE)
  commits <- commits %>%
    mutate(name = repo,   # Ajouter le nom du projet
           type = "commit",       # Spécifier le type comme "commit"
           message = commit.message,  # Utiliser le message du commit
           author = commit.committer.email , # Ajout de l'auteur
           updated_at = commit.committer.date) %>%  # Date de la dernière mise à jour
    select(name, type, message, updated_at,author)  # Conserver les colonnes pertinentes
  return(commits)
}

# Fonction pour récupérer les issues d'un projet GitHub avec clé API
get_github_issues <- function(repo) {
  url <- paste0("https://api.github.com/repos/", repo, "/issues?state=all")
  response <- GET(url, authenticate(Sys.getenv("GITHUB_PAT"), ""))  # Utilisation de la clé API
  if (status_code(response) != 200) {
    stop("Failed to fetch issues from GitHub API")
  }
  issues <- fromJSON(content(response, "text"), flatten = TRUE)
  issues <- issues %>%
    mutate(name = repo,   # Ajouter le nom du projet
           type = "issue",        # Spécifier le type comme "issue"
           message = title,       # Utiliser le titre de l'issue
           author = user.login , # Ajout de l'auteur
           updated_at = updated_at) %>%  # Date de la dernière mise à jour
    select(name, type, message, updated_at,author)  # Conserver les colonnes pertinentes
  return(issues)
}

get_github_topics <- function(repo) {
  url <- paste0("https://api.github.com/repos/", repo, "/topics")
  response <- GET(url, authenticate(Sys.getenv("GITHUB_PAT"), ""), add_headers(Accept = "application/vnd.github.mercy-preview+json"))
  if (status_code(response) != 200) {
    stop("Failed to fetch topics from GitHub API for repo: ", repo)
  }
  topics <- fromJSON(content(response, "text"), flatten = TRUE)$names
  return(data.frame(name = repo, topics = paste(topics, collapse = ", "))) # Combine topics en une chaîne unique
}


 # Récupérer les commits et les issues pour le projet spyrales/shinygouv
 repo_shinygouv <- "spyrales/shinygouv"
 commits_shinygouv <- get_github_commits(repo_shinygouv)
 issues_shinygouv <- get_github_issues(repo_shinygouv)

 # Récupérer les commits et les issues pour le projet spyrales/gouvdown
 repo_gouvdown <- "spyrales/gouvdown"
 commits_gouvdown <- get_github_commits(repo_gouvdown)
 issues_gouvdown <- get_github_issues(repo_gouvdown)

 # parcours_r_module_applications_shiny
 repo_app_shiny <- "MTES-MCT/parcours_r_module_applications_shiny"
 commits_app_shiny <- get_github_commits(repo_app_shiny)
 issues_app_shiny <- get_github_commits(repo_app_shiny)

 # parcours-r_ateliers_rpackage
 repo_ateliers_rpackage <- "MTES-MCT/parcours-r_ateliers_rpackage"
 commits_ateliers_rpackage <- get_github_commits(repo_ateliers_rpackage)
 issues_ateliers_rpackage <- get_github_commits(repo_ateliers_rpackage)

 # parcours_r_module_analyse_multi_dimensionnelles
 repo_analyse_multi_dimensionnelles <- "MTES-MCT/parcours_r_module_analyse_multi_dimensionnelles"
 commits_multi_dim <- get_github_commits(repo_analyse_multi_dimensionnelles)
 issues_multi_dim <- get_github_issues(repo_analyse_multi_dimensionnelles)

 # parcours_r_module_statistiques_descriptives
 repo_stat_desc <- "MTES-MCT/parcours_r_module_statistiques_descriptives"
 commits_stat_desc <- get_github_commits(repo_stat_desc)
 issues_stat_desc <- get_github_issues(repo_stat_desc)

 # parcours_r_module_publication_rmarkdown
 repo_rmarkdown <- "MTES-MCT/parcours_r_module_publication_rmarkdown"
 commits_rmarkdown <- get_github_commits(repo_rmarkdown)
 issues_rmarkdown <- get_github_issues(repo_rmarkdown)
 # parcours_r_socle_introduction
 repo_introduction <- "MTES-MCT/parcours_r_socle_introduction"
 commits_introduction <- get_github_commits(repo_introduction)
 issues_introduction <- get_github_issues(repo_introduction)

 # parcours_r_socle_preparation_des_donnees
 repo_preparation_des_donnees <- "MTES-MCT/parcours_r_socle_preparation_des_donnees"
 commits_preparation_des_donnees <- get_github_commits(repo_preparation_des_donnees)
 issues_preparation_des_donnees <- get_github_issues(repo_preparation_des_donnees)

 # savoirfR
 repo_savoirfR <- "MTES-MCT/savoirfR"
 commits_savoirfR <- get_github_commits(repo_savoirfR)
 issues_savoirfR <- get_github_issues(repo_savoirfR)

 # parcours-r
 repo_parcours_r <- "MTES-MCT/parcours-r"
 commits_parcours_r <- get_github_commits(repo_parcours_r)
 issues_parcours_r <- get_github_issues(repo_parcours_r)

 # parcours_r_module_datavisualisation
 repo_datavisualisation <- "MTES-MCT/parcours_r_module_datavisualisation"
 commits_datavisualisation <- get_github_commits(repo_datavisualisation)
 issues_datavisualisation <- get_github_issues(repo_datavisualisation)

 # parcours_r_module_analyse_spatiale
 repo_analyse_spatiale <- "MTES-MCT/parcours_r_module_analyse_spatiale"
 commits_analyse_spatiale <- get_github_commits(repo_analyse_spatiale)
 issues_analyse_spatiale <- get_github_issues(repo_analyse_spatiale)

 # COGiter
 repo_cogiter <- "MaelTheuliere/COGiter"
 commits_cogiter <- get_github_commits(repo_cogiter)
 issues_cogiter <- get_github_issues(repo_cogiter)

 repos <- c(
   "spyrales/shinygouv", "spyrales/gouvdown",
   "MTES-MCT/parcours_r_module_applications_shiny",
   "MTES-MCT/parcours-r_ateliers_rpackage",
   "MTES-MCT/parcours_r_module_analyse_multi_dimensionnelles",
   "MTES-MCT/parcours_r_module_statistiques_descriptives",
   "MTES-MCT/parcours_r_module_publication_rmarkdown",
   "MTES-MCT/parcours_r_socle_introduction",
   "MTES-MCT/parcours_r_socle_preparation_des_donnees",
   "MTES-MCT/savoirfR", "MTES-MCT/parcours-r",
   "MTES-MCT/parcours_r_module_datavisualisation",
   "MTES-MCT/parcours_r_module_analyse_spatiale",
   "MaelTheuliere/COGiter"
 )

 topics_list <- do.call(rbind, lapply(repos, get_github_topics))

 # Combiner les dataframes de commits et issues pour les deux dépôts
 combined_data <- bind_rows(commits_shinygouv, issues_shinygouv,
                            commits_gouvdown, issues_gouvdown,
                            commits_app_shiny, issues_app_shiny,
                            commits_ateliers_rpackage, issues_ateliers_rpackage,
                            commits_multi_dim, issues_multi_dim,
                            commits_stat_desc, issues_stat_desc,
                            commits_rmarkdown, issues_rmarkdown,
                            commits_introduction, issues_introduction,
                            commits_preparation_des_donnees, issues_preparation_des_donnees,
                            commits_savoirfR, issues_savoirfR,
                            commits_parcours_r, issues_parcours_r,
                            commits_datavisualisation, issues_datavisualisation,
                            commits_analyse_spatiale, issues_analyse_spatiale,
                            commits_cogiter,issues_cogiter
                            )

 rm(commits_shinygouv, issues_shinygouv,
    commits_gouvdown, issues_gouvdown,
    commits_app_shiny, issues_app_shiny,
    commits_ateliers_rpackage, issues_ateliers_rpackage,
    commits_multi_dim, issues_multi_dim,
    commits_stat_desc, issues_stat_desc,
    commits_rmarkdown, issues_rmarkdown,
    commits_introduction, issues_introduction,
    commits_preparation_des_donnees, issues_preparation_des_donnees,
    commits_savoirfR, issues_savoirfR,
    commits_parcours_r, issues_parcours_r,
    commits_datavisualisation, issues_datavisualisation,
    commits_analyse_spatiale, issues_analyse_spatiale,
    commits_cogiter,issues_cogiter
 )

 combined_data <- combined_data %>%
   left_join(topics_list, by = "name") %>%
   mutate(origine = "Github",
          groupe = case_when(
            str_detect(name, "parcours_r") ~ "r-formation",
            str_detect(name, "spyrales") ~ "spyrales",
            TRUE ~ "autre"
          )) %>%
   unique()

# Afficher les premières lignes du tableau combiné
date_datamart <-format.Date(Sys.Date(), '%d/%m/%Y')
#save.image("github.RData")
save(combined_data, file = "github.RData")
save(date_datamart, file = "date_MAJ.RData")
