ui <- shinygouv::navbarPage_dsfr(
  # header & footer ------
  title = "Dataviz GitlabR",
  id = "nav",
  header = shinygouv::header_dsfr(
    intitule = c("DREAL", "Pays de la Loire"),
    nom_site_service = "Visualisation des projets du CSD gérés avec git",
    baseline = "Les Projets du Centre de Services de la Donnée"
  ),
  footer = shinygouv::footer_dsfr(
    intitule = c("DREAL", "Pays de la Loire"),
    description = paste("Site mis à jour le : " , date_datamart),
    accessibilite = "non",
    add_extra_url_body = shinygouv::footer_extra_url_body_dsfr(),
    add_extra_url_bottom = shinygouv::footer_extra_url_bottom_dsfr()
  ),
  # First tab Projet ---------
  shinygouv::navbarPanel_dsfr(
    title = "Graphique par période",
    htmltools::tags$head(tags$style(".fr-container { max-width: calc(100% - 2rem); }")),
    shinygouv::fluidRow_dsfr(
      shinygouv::column_dsfr(
        3,
        shinygouv::dateRangeInput_dsfr(
          inputId = "daterange",
          label = "Sélectionnez une période :",
          start = format(Sys.Date() - 7, format = "%Y-%m-%d"),
          separator = "à"
        ),
        extra_class = "fr-mt-6w"
      ),
      shinygouv::column_dsfr(
        3,
        shiny::selectizeInput(
          inputId = "etiquette",
          label = "Étiquette :",
          choices = all_data$etiquette %>%
            strsplit(split = ",") %>%  # Divise les chaînes en éléments séparés
            unlist() %>%               # Aplatit la liste obtenue
            stats::na.omit() %>%              # Supprime les NA (au cas où)
            .[. != ""] %>%             # Supprime les chaînes vides
            trimws() %>%                # suppremie les espace avnt et apres
            unique() ,
          # Extrait les éléments uniques
          multiple = TRUE
        ),
        extra_class = "fr-mt-6w"
      ),
      shinygouv::column_dsfr(
        3,
        shiny::selectizeInput(
          inputId = "project_name",
          label = "Sélectionnez projet : ",
          choices = NULL,
          multiple = TRUE
        ),
        extra_class = "fr-mt-6w"
      ),
      shinygouv::column_dsfr(
        3,
        shiny::selectizeInput(
          inputId = "auteur",
          label = "Auteur :",
          choices = unique(stringr::str_to_title(textclean::replace_non_ascii(all_data$auteur))),
          selected = NULL,
          multiple = TRUE
        ),extra_class = "fr-mt-6w"
      ),
      shinygouv::column_dsfr(
        3,
        shinygouv::actionButton_dsfr("reset", "Réinitialiser les projets"),
        extra_class = "fr-my-2w"
      ),
      shinygouv::column_dsfr(
        4,
        shinygouv::checkboxGroupInput_dsfr(
          inputId = "re_code",
          label = "Type d'évènement :",
          choices = unique(all_data$re_code),
          inline = TRUE
        )
      ),
      shinygouv::column_dsfr(
        4,
        shiny::selectizeInput(
          inputId = "categorie",
          label = " Évenement (précis) ",
          choices = unique(all_data$type),
          selected = NULL,
          multiple = TRUE
        )
      ),
      shinygouv::column_dsfr(9, shiny::uiOutput("lien"), extra_class = "fr-my-6w")
    ),
    shinygouv::tabsetPanel_dsfr(
      "tableau_proj",
      shinygouv::tabPanel_dsfr(
        id = "graph_input",
        title = "graphique par choix",
        shinygouv::fluidRow_dsfr(
          shinygouv::column_dsfr(
            12,
            plotly::plotlyOutput("filteredPlot2", height = "700px"),
            extra_class = "fr-my-1w"
          )
        )
      ),# tab graphique par choix ↑
      shinygouv::tabPanel_dsfr(
        id = "indicateur" ,
        title = "Indicateurs",
        shinygouv::fluidRow_dsfr(
          shinygouv::column_dsfr(3,
                      shiny::textOutput("nb_projet"),
                      shiny::textOutput("nb_commit"),
                      shiny::textOutput("nb_temps"), extra_class = "fr-my-1w"
          ),
          shinygouv::column_dsfr(9,
                                 plotly::plotlyOutput("bar_chart"),
                                 extra_class = "fr-my-1w"),

          shinygouv::column_dsfr(12,shiny::textOutput("min_value")),
          shinygouv::column_dsfr(12,shiny::textOutput("temps")),
          shinygouv::column_dsfr(12,shiny::plotOutput("bar"),
                      extra_class = "fr-my-1w")
        )
      ),# tab indicateur par choix ↑
      shinygouv::tabPanel_dsfr(
        id = "Table" ,
        title = "Table",
        shinygouv::fluidRow_dsfr(
          shinygouv::column_dsfr(12,
                                 DT::DTOutput('table'))
        )
      )# tab table par choix ↑
    )#↑ tableau_proj
  )# ↑ Navbar
)# ↑ UI
